/* progress_box.c generated by valac 0.56.17, the Vala compiler
 * generated from progress_box.vala, do not modify */

/*
 *  pamac-vala
 *
 *  Copyright (C) 2014-2022 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "pamac-gtk.h"
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	PAMAC_PROGRESS_BOX_0_PROPERTY,
	PAMAC_PROGRESS_BOX_NUM_PROPERTIES
};
static GParamSpec* pamac_progress_box_properties[PAMAC_PROGRESS_BOX_NUM_PROPERTIES];

static gpointer pamac_progress_box_parent_class = NULL;

static void pamac_progress_box_finalize (GObject * obj);
static GType pamac_progress_box_get_type_once (void);

PamacProgressBox*
pamac_progress_box_construct (GType object_type)
{
	PamacProgressBox * self = NULL;
	self = (PamacProgressBox*) g_object_new (object_type, NULL);
	return self;
}

PamacProgressBox*
pamac_progress_box_new (void)
{
	return pamac_progress_box_construct (PAMAC_TYPE_PROGRESS_BOX);
}

static void
pamac_progress_box_class_init (PamacProgressBoxClass * klass,
                               gpointer klass_data)
{
	pamac_progress_box_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = pamac_progress_box_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/manjaro/pamac/transaction/progress_box.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "progressbar", FALSE, G_STRUCT_OFFSET (PamacProgressBox, progressbar));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "action_label", FALSE, G_STRUCT_OFFSET (PamacProgressBox, action_label));
}

static void
pamac_progress_box_instance_init (PamacProgressBox * self,
                                  gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
pamac_progress_box_finalize (GObject * obj)
{
	PamacProgressBox * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_PROGRESS_BOX, PamacProgressBox);
	G_OBJECT_CLASS (pamac_progress_box_parent_class)->finalize (obj);
}

static GType
pamac_progress_box_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacProgressBoxClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_progress_box_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacProgressBox), 0, (GInstanceInitFunc) pamac_progress_box_instance_init, NULL };
	GType pamac_progress_box_type_id;
	pamac_progress_box_type_id = g_type_register_static (gtk_box_get_type (), "PamacProgressBox", &g_define_type_info, 0);
	return pamac_progress_box_type_id;
}

GType
pamac_progress_box_get_type (void)
{
	static volatile gsize pamac_progress_box_type_id__once = 0;
	if (g_once_init_enter (&pamac_progress_box_type_id__once)) {
		GType pamac_progress_box_type_id;
		pamac_progress_box_type_id = pamac_progress_box_get_type_once ();
		g_once_init_leave (&pamac_progress_box_type_id__once, pamac_progress_box_type_id);
	}
	return pamac_progress_box_type_id__once;
}

