/* summary_row.c generated by valac 0.56.17, the Vala compiler
 * generated from summary_row.vala, do not modify */

/*
 *  pamac-vala
 *
 *  Copyright (C) 2022 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include "pamac-gtk.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define PAMAC_TYPE_SUMMARY_ROW (pamac_summary_row_get_type ())
#define PAMAC_SUMMARY_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_SUMMARY_ROW, PamacSummaryRow))
#define PAMAC_SUMMARY_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_SUMMARY_ROW, PamacSummaryRowClass))
#define PAMAC_IS_SUMMARY_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_SUMMARY_ROW))
#define PAMAC_IS_SUMMARY_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_SUMMARY_ROW))
#define PAMAC_SUMMARY_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_SUMMARY_ROW, PamacSummaryRowClass))

typedef struct _PamacSummaryRow PamacSummaryRow;
typedef struct _PamacSummaryRowClass PamacSummaryRowClass;
typedef struct _PamacSummaryRowPrivate PamacSummaryRowPrivate;
enum  {
	PAMAC_SUMMARY_ROW_0_PROPERTY,
	PAMAC_SUMMARY_ROW_NUM_PROPERTIES
};
static GParamSpec* pamac_summary_row_properties[PAMAC_SUMMARY_ROW_NUM_PROPERTIES];

struct _PamacSummaryRow {
	GtkListBoxRow parent_instance;
	PamacSummaryRowPrivate * priv;
	GtkImage* app_icon;
	GtkLabel* name_label;
	GtkLabel* infos_label;
	GtkLabel* version_label;
	GtkLabel* repo_label;
	GtkLabel* size_label;
};

struct _PamacSummaryRowClass {
	GtkListBoxRowClass parent_class;
};

static gpointer pamac_summary_row_parent_class = NULL;

VALA_EXTERN GType pamac_summary_row_get_type (void) G_GNUC_CONST ;
VALA_EXTERN PamacSummaryRow* pamac_summary_row_new (void);
VALA_EXTERN PamacSummaryRow* pamac_summary_row_construct (GType object_type);
static void pamac_summary_row_finalize (GObject * obj);
static GType pamac_summary_row_get_type_once (void);

PamacSummaryRow*
pamac_summary_row_construct (GType object_type)
{
	PamacSummaryRow * self = NULL;
	self = (PamacSummaryRow*) g_object_new (object_type, NULL);
	return self;
}

PamacSummaryRow*
pamac_summary_row_new (void)
{
	return pamac_summary_row_construct (PAMAC_TYPE_SUMMARY_ROW);
}

static void
pamac_summary_row_class_init (PamacSummaryRowClass * klass,
                              gpointer klass_data)
{
	pamac_summary_row_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = pamac_summary_row_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/manjaro/pamac/transaction/summary_row.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "app_icon", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, app_icon));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "name_label", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, name_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "infos_label", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, infos_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "version_label", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, version_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "repo_label", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, repo_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "size_label", FALSE, G_STRUCT_OFFSET (PamacSummaryRow, size_label));
}

static void
pamac_summary_row_instance_init (PamacSummaryRow * self,
                                 gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
pamac_summary_row_finalize (GObject * obj)
{
	PamacSummaryRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PAMAC_TYPE_SUMMARY_ROW, PamacSummaryRow);
	G_OBJECT_CLASS (pamac_summary_row_parent_class)->finalize (obj);
}

static GType
pamac_summary_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacSummaryRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_summary_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacSummaryRow), 0, (GInstanceInitFunc) pamac_summary_row_instance_init, NULL };
	GType pamac_summary_row_type_id;
	pamac_summary_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "PamacSummaryRow", &g_define_type_info, 0);
	return pamac_summary_row_type_id;
}

GType
pamac_summary_row_get_type (void)
{
	static volatile gsize pamac_summary_row_type_id__once = 0;
	if (g_once_init_enter (&pamac_summary_row_type_id__once)) {
		GType pamac_summary_row_type_id;
		pamac_summary_row_type_id = pamac_summary_row_get_type_once ();
		g_once_init_leave (&pamac_summary_row_type_id__once, pamac_summary_row_type_id);
	}
	return pamac_summary_row_type_id__once;
}

