/* back_row.c generated by valac 0.56.17, the Vala compiler
 * generated from back_row.vala, do not modify */

/*
 *  pamac-vala
 *
 *  Copyright (C) 2022 Guillaume Benoit <guillaume@manjaro.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a get of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define PAMAC_TYPE_BACK_ROW (pamac_back_row_get_type ())
#define PAMAC_BACK_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PAMAC_TYPE_BACK_ROW, PamacBackRow))
#define PAMAC_BACK_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PAMAC_TYPE_BACK_ROW, PamacBackRowClass))
#define PAMAC_IS_BACK_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PAMAC_TYPE_BACK_ROW))
#define PAMAC_IS_BACK_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PAMAC_TYPE_BACK_ROW))
#define PAMAC_BACK_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PAMAC_TYPE_BACK_ROW, PamacBackRowClass))

typedef struct _PamacBackRow PamacBackRow;
typedef struct _PamacBackRowClass PamacBackRowClass;
typedef struct _PamacBackRowPrivate PamacBackRowPrivate;
enum  {
	PAMAC_BACK_ROW_0_PROPERTY,
	PAMAC_BACK_ROW_NUM_PROPERTIES
};
static GParamSpec* pamac_back_row_properties[PAMAC_BACK_ROW_NUM_PROPERTIES];

struct _PamacBackRow {
	GtkListBoxRow parent_instance;
	PamacBackRowPrivate * priv;
};

struct _PamacBackRowClass {
	GtkListBoxRowClass parent_class;
};

static gpointer pamac_back_row_parent_class = NULL;

VALA_EXTERN GType pamac_back_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PamacBackRow, g_object_unref)
VALA_EXTERN PamacBackRow* pamac_back_row_new (void);
VALA_EXTERN PamacBackRow* pamac_back_row_construct (GType object_type);
static GType pamac_back_row_get_type_once (void);

PamacBackRow*
pamac_back_row_construct (GType object_type)
{
	PamacBackRow * self = NULL;
	self = (PamacBackRow*) g_object_new (object_type, NULL);
	return self;
}

PamacBackRow*
pamac_back_row_new (void)
{
	return pamac_back_row_construct (PAMAC_TYPE_BACK_ROW);
}

static void
pamac_back_row_class_init (PamacBackRowClass * klass,
                           gpointer klass_data)
{
	pamac_back_row_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/manjaro/pamac/manager/back_row.ui");
}

static void
pamac_back_row_instance_init (PamacBackRow * self,
                              gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static GType
pamac_back_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PamacBackRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) pamac_back_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PamacBackRow), 0, (GInstanceInitFunc) pamac_back_row_instance_init, NULL };
	GType pamac_back_row_type_id;
	pamac_back_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "PamacBackRow", &g_define_type_info, 0);
	return pamac_back_row_type_id;
}

GType
pamac_back_row_get_type (void)
{
	static volatile gsize pamac_back_row_type_id__once = 0;
	if (g_once_init_enter (&pamac_back_row_type_id__once)) {
		GType pamac_back_row_type_id;
		pamac_back_row_type_id = pamac_back_row_get_type_once ();
		g_once_init_leave (&pamac_back_row_type_id__once, pamac_back_row_type_id);
	}
	return pamac_back_row_type_id__once;
}

